Daemon

Struct Daemon 

pub struct Daemon { /* private fields */ }
Connection to the user’s uniauth daemon, used for RPC Connection with the daemon will last as long as this struct exists. Should only be used by an application’s client, never a server.

Implementations

Source

impl Daemon

pub async fn new(service: &str) -> Result<Self>

Connect to the default daemon path.

Arguments
  • service - Name of this service
Example
let daemon = Daemon::new("matrix").await?;
pub async fn connect(service: &str, path: impl AsRef<Path>) -> Result<Self>

Connect to a custom daemon path

Arguments
  • service - Name of this service
  • path - Path to the daemon’s unix socket
Example
let daemon = Daemon::connect("test_thing", "/tmp/test.sock").await?;
pub async fn authenticate( &mut self, name: &str, action: &str, nonce: &[u8], ) -> Result<AnySignature>

Authenticate an action for a given service login, returning its signature. All fields must be known by the server to authenticate with through communication or hardcoding.

Arguments
  • name - Name of the service’s key to use
  • action - Action to authenticate. Must be human readable, but also completely deterministic
  • nonce - Unique random data or atomic counter that is unique to this challenge and never used again
Example
let nonce = random_data_from_server();
let sig = daemon.authenticate("username", "login", &nonce).await?;
send_signature_to_server(sig);
pub async fn pubkey(&mut self, name: &str) -> Result<AnyPubkey>

Get the public key for a given name

Arguments
  • name - Name of the key as added with store
Example
let pubkey = daemon.pubkey("username").await?;
send_server_pubkey(pubkey);
// have the server verify a regsiter action now
pub async fn store(&mut self, name: &str, keypair: AnyKeypair) -> Result<()>

Store a keypair for a new service login. Will fail if a keypair already exists.

Warning

Since the client provides the keypair, this gives it a requirement for extra security. Keys that are generated and immediately stored should use generate instead.

Arguments
  • name - Name of the key to be retrieved by authenticate or pubkey
  • keypair - The keypair used for signing challenges
Example
let keypair = import_keypair();
daemon.store("username", keypair).await?;
pub async fn generate(&mut self, name: &str) -> Result<AnyPubkey>

Generate a new keypair and return its public half. Will fail if a keypair already exists

Arguments
  • name - Name of the key to generate
Example
let pubkey = daemon.generate("username").await?;
pubkey.verify(b"whatever", signature)?;